@@ -7,7 +7,7 @@ use warnings;
 use 5.8.0;
 
 package Net::DHCP::Packet;
-$Net::DHCP::Packet::VERSION = '0.7_003';
+$Net::DHCP::Packet::VERSION = '0.7_004';
 use Carp;
 use Net::DHCP::Constants qw(:DEFAULT :dhcp_hashes :dhcp_other %DHO_FORMATS);
 use Net::DHCP::Packet::Attributes qw(:all);
@@ -108,22 +108,6 @@ sub new {
 
 }
 
-sub optionsorder {
-
-    # 53 54 55 51 at the start
-    return -1 if $a == 53;
-    return -1 if $a == 54;
-    return -1 if $a == 55;
-    return -1 if $a == 51;
-
-    # 82 at the end
-    return 1 if $a == 82;
-
-    # 60 needs to be immediately before 43. not sure how
-    $a <=> $b
-
-}
-
 sub addOptionRaw {
     my ( $self, $key, $value_bin, $sort ) = @_;
     $self->{options}->{$key} = $value_bin;
@@ -131,7 +115,7 @@ sub addOptionRaw {
 
     return 1 if $sort;
 
-    @{ $self->{options_order} } = sort optionsorder @{ $self->{options_order} };
+#FIXME    @{ $self->{options_order} } = sort optionsorder @{ $self->{options_order} };
 
     return 1
 }
@@ -191,6 +175,7 @@ sub addOptionValue {
         },
         string     => sub { return shift },
         clientid   => sub { return packclientid(shift) },
+        sipserv    => sub { return packsipserv(shift) },
         csr        => sub { return packcsr(shift) },
         suboptions => sub { return packsuboptions(@_) },
 
@@ -334,6 +319,7 @@ sub getOptionValue {
         bytes  => sub { return unpack( 'C*', shift ) },
         string => sub { return shift },
         clientid   => sub { return unpackclientid(shift) },
+        sipserv    => sub { return unpacksipserv(shift) },
         csr        => sub { return unpackcsr(shift) },
         suboptions => sub { return unpacksuboptions(shift) },
 
@@ -661,6 +647,7 @@ sub toString {
             }
             else {
                 $value = $self->getOptionRaw($key);
+		print "went here for $key\n";
             }
 
             # convert to printable text
@@ -741,7 +728,28 @@ sub unpackclientid {
 
     return $clientid
 
-   #croak('unpack clientid field still WIP');
+}
+
+sub packsipserv {
+   return shift
+   # croak('pack sipserv field still WIP');
+}
+
+sub unpacksipserv {
+
+    my $sipserv = shift
+      or return;
+
+    my $type = unpack('C',substr( $sipserv, 0, 1 ));
+
+#    if ($type == 0) { # text
+#        return substr( $sipserv, 1, length($clientid) )
+#    }
+    if ($type == 1) { # ipv4
+        return unpackinet(substr( $sipserv, 1, length($sipserv) ))
+    }
+
+    return $sipserv
 
 }
 
@@ -787,7 +795,7 @@ Net::DHCP::Packet - Object methods to create a DHCP packet.
 
 =head1 VERSION
 
-version 0.7_003
+version 0.7_004
 
 =head1 SYNOPSIS
 
@@ -1003,12 +1011,24 @@ returns the packed Client-identifier (pass-through currently)
 
 =item I<unpackclientid>
 
-returns the unpackged clientid.
+returns the unpacked clientid.
 
 Decodes:
  type 0 as a string
  type 1 as a mac address (hex string)
- everything is passes through
+ everything is passed through
+
+=item I<packsipserv( VALUE)>
+
+returns the packed sip server field (pass-through currently)
+
+=item I<unpacksipserv>
+
+returns the unpacked sip server.
+
+Decodes:
+ type 1 as an ipv4 address
+ everything is passed through
 
 =item I<packcsr( ARRAYREF )>
 
@@ -1243,11 +1263,6 @@ For option 43 (vendor specific), 82 (relay agent) etc.
 
 Unpacks sub-options to a list of lists
 
-=item optionsorder ( )
-
-TODO This will rearrange the order of options to accomidate as many
-quirky cliens as possible.
-
 =back
 
 See also L<Net::DHCP::Packet::IPv4Utils>
@@ -1336,14 +1351,6 @@ A simple DHCP Server is provided in the "examples" directory. It is composed of
 "dhcpd.pl" a *very* simple server example, and "dhcpd_test.pl" a simple tester for
 this server.
 
-=head1 QUIRK WORK-AROUNDS
-
-Cable vendors really want option 82 to always be last.
-
-Intel PXE really wants option 60 before option 43.
-
-Minimum frame size is 300, but we only warn (carp) if its not.
-
 =head1 AUTHOR
 
 Dean Hamstead E<lt>dean@bytefoundry.com.au<gt>
@@ -1367,6 +1374,7 @@ Perl itself.
 
 =head1 SEE ALSO
 
-L<Net::DHCP::Options>, L<Net::DHCP::Constants>.
+L<Net::DHCP::Options>, L<Net::DHCP::Constants>, L<Net::DHCP::IPv4Utils>,
+L<Net::DHCP::Attributes>, L<Net::DHCP::OrderOptions>.
 
 =cut
